@@ -21,7 +21,7 @@
 
 #include <AkonadiCore/attribute.h>
 
-#include <QtCore/QString>
+#include <QString>
 
 class CTagAttribute : public Akonadi::Attribute
 {
@@ -31,10 +31,10 @@ public:
     void setCTag(const QString &ctag);
     QString CTag() const;
 
-    Akonadi::Attribute *clone() const Q_DECL_OVERRIDE;
-    QByteArray type() const Q_DECL_OVERRIDE;
-    QByteArray serialized() const Q_DECL_OVERRIDE;
-    void deserialize(const QByteArray &data) Q_DECL_OVERRIDE;
+    Akonadi::Attribute *clone() const override;
+    QByteArray type() const override;
+    QByteArray serialized() const override;
+    void deserialize(const QByteArray &data) override;
 
 private:
     QString mCTag;
