@@ -67,7 +67,7 @@
 #include <KLocalizedString>
 #include "davresource_debug.h"
 
-#include <QtCore/QSet>
+#include <QSet>
 #include <QtDBus/QDBusConnection>
 
 using namespace Akonadi;
@@ -152,9 +152,9 @@ void DavGroupwareResource::cleanup()
     Akonadi::AgentBase::cleanup();
 }
 
-KDateTime DavGroupwareResource::lastCacheUpdate() const
+QDateTime DavGroupwareResource::lastCacheUpdate() const
 {
-    return KDateTime::currentLocalDateTime();
+    return QDateTime::currentDateTime();
 }
 
 void DavGroupwareResource::canHandleFreeBusy(const QString &email) const
@@ -171,7 +171,7 @@ void DavGroupwareResource::onHandlesFreeBusy(const QString &email, bool handles)
     handlesFreeBusy(email, handles);
 }
 
-void DavGroupwareResource::retrieveFreeBusy(const QString &email, const KDateTime &start, const KDateTime &end)
+void DavGroupwareResource::retrieveFreeBusy(const QString &email, const QDateTime &start, const QDateTime &end)
 {
     if (!isOnline()) {
         freeBusyRetrieved(email, QString(), false, i18n("Unable to retrieve free-busy info while offline"));
@@ -906,7 +906,7 @@ void DavGroupwareResource::onMultigetFinished(KJob *job)
     const KDAV::DavItemsFetchJob *davJob = qobject_cast< KDAV::DavItemsFetchJob *>(job);
 
     Akonadi::Item::List items;
-    foreach (Akonadi::Item item, origItems) {   //krazy:exclude=foreach non-const is intended here
+    for (Akonadi::Item item : qAsConst(origItems)) {   //krazy:exclude=foreach non-const is intended here
         const KDAV::DavItem davItem = davJob->item(item.remoteId());
 
         // No data was retrieved for this item, maybe because it is not out of date
@@ -929,7 +929,7 @@ void DavGroupwareResource::onMultigetFinished(KJob *job)
         item.setRemoteRevision(davItem.etag());
         cache->setEtag(item.remoteId(), davItem.etag());
         items << item;
-        foreach (const Akonadi::Item &extraItem, extraItems) {
+        for (const Akonadi::Item &extraItem : qAsConst(extraItems)) {
             cache->setEtag(extraItem.remoteId(), davItem.etag());
             items << extraItem;
         }
@@ -1174,8 +1174,8 @@ void DavGroupwareResource::handleConflict(const Item &lI, const Item::List &loca
         }
 
         // Now try to find the item that really triggered the conflict
-        Akonadi::Item::List allRemoteItems; allRemoteItems << tmpRemoteItem << tmpRemoteDependentItems;
-        foreach (const Akonadi::Item &tmpItem, allRemoteItems) {
+        const Akonadi::Item::List allRemoteItems  = Akonadi::Item::List() << tmpRemoteItem << tmpRemoteDependentItems;
+        for (const Akonadi::Item &tmpItem : allRemoteItems) {
             if (tmpItem.payloadData() != localItem.payloadData()) {
                 if (remoteItem.isValid()) {
                     // Oops, we can only manage one changed item at this stage, sorry...
