@@ -36,7 +36,7 @@
 #include <QDebug>
 #include <QIcon>
 
-#include <QtCore/QPointer>
+#include <QPointer>
 
 #include <KGAPI/Types>
 #include <KGAPI/Account>
@@ -347,7 +347,7 @@ void ContactsResource::slotCollectionsRetrieved(KGAPI2::Job *job)
 
     m_collections[ MYCONTACTS_REMOTEID ] = m_rootCollection;
 
-    foreach (const ObjectPtr &object, objects) {
+    for (const ObjectPtr &object : qAsConst(objects)) {
         const ContactsGroupPtr group = object.dynamicCast<ContactsGroup>();
 
         QString realName = group->title();
@@ -507,7 +507,7 @@ void ContactsResource::slotUpdatePhotoFinished(KGAPI2::Job *job, const ContactPt
     job->setProperty("processedItems", processedItems);
     emitPercent(job, processedItems, items.count());
 
-    foreach (Item item, items) {
+    for (Item item : qAsConst(items)) {
         if (item.remoteId() == contact->uid()) {
             item.setPayload<KContacts::Addressee>(*contact.dynamicCast<KContacts::Addressee>());
             new ItemModifyJob(item, this);
