@@ -24,7 +24,7 @@
 */
 
 #include "imapresourcebase.h"
-#include "helper_p.h"
+
 
 #include <QHostInfo>
 #include <QSettings>
@@ -126,6 +126,7 @@ ImapResourceBase::ImapResourceBase(const QString &id)
     changeRecorder()->fetchCollection(true);
     changeRecorder()->collectionFetchScope().setAncestorRetrieval(CollectionFetchScope::All);
     changeRecorder()->collectionFetchScope().setIncludeStatistics(true);
+    changeRecorder()->collectionFetchScope().fetchAttribute<CollectionAnnotationsAttribute>();
     changeRecorder()->itemFetchScope().fetchFullPayload(true);
     changeRecorder()->itemFetchScope().setAncestorRetrieval(ItemFetchScope::All);
     changeRecorder()->itemFetchScope().setFetchModificationTime(false);
@@ -264,11 +265,7 @@ int ImapResourceBase::configureSubscription(qlonglong windowId)
 
     mSubscriptions = new SubscriptionDialog(nullptr, SubscriptionDialog::AllowToEnableSubscription);
     if (windowId) {
-#ifndef Q_OS_WIN
         KWindowSystem::setMainWindow(mSubscriptions, windowId);
-#else
-        KWindowSystem::setMainWindow(mSubscriptions, (HWND)windowId);
-#endif
     }
     mSubscriptions->setWindowTitle(i18nc("@title:window", "Serverside Subscription"));
     mSubscriptions->setWindowIcon(QIcon::fromTheme(QStringLiteral("network-server")));
