@@ -36,14 +36,11 @@ public:
 
 private Q_SLOTS:
     void onSelectDone(KJob *job);
-    void onMessagesReceived(const QString &mailBox,
-                            const QMap<qint64, qint64> &uids,
-                            const QMap<qint64, KIMAP::MessageAttribute> &attrs,
-                            const QMap<qint64, KIMAP::MessagePtr> &messages);
+    void onMessagesReceived(const QMap<qint64, KIMAP::Message> &messages);
     void onContentFetchDone(KJob *job);
 
 protected:
-    void doStart(KIMAP::Session *session) Q_DECL_OVERRIDE;
+    void doStart(KIMAP::Session *session) override;
 
 private:
     void triggerFetchJob();
