@@ -158,7 +158,7 @@ QByteArray O1::getRequestBase(const QList<O0RequestParameter> &oauthParams, cons
     // Append a sorted+encoded list of all request parameters to the base string
     QList<O0RequestParameter> headers(oauthParams);
     headers.append(otherParams);
-    qSort(headers);
+    std::sort(headers.begin(), headers.end());
     base.append(encodeHeaders(headers));
 
     return base;
@@ -180,8 +180,8 @@ QByteArray O1::buildAuthorizationHeader(const QList<O0RequestParameter> &oauthPa
     bool first = true;
     QByteArray ret("OAuth ");
     QList<O0RequestParameter> headers(oauthParams);
-    qSort(headers);
-    foreach (const O0RequestParameter &h, headers) {
+    std::sort(headers.begin(), headers.end());
+    for (const O0RequestParameter &h : qAsConst(headers)) {
         if (first) {
             first = false;
         } else {
@@ -371,7 +371,7 @@ void O1::onTokenExchangeFinished()
         // Set extra tokens if any
         if (!response.isEmpty()) {
             QVariantMap extraTokens;
-            foreach (QString key, response.keys()) {
+            foreach (const QString &key, response.keys()) {
                 extraTokens.insert(key, response.value(key));
             }
             setExtraTokens(extraTokens);
@@ -387,7 +387,7 @@ void O1::onTokenExchangeFinished()
 QMap<QString, QString> O1::parseResponse(const QByteArray &response)
 {
     QMap<QString, QString> ret;
-    foreach (QByteArray param, response.split('&')) {
+    foreach (const QByteArray &param, response.split('&')) {
         QList<QByteArray> kv = param.split('=');
         if (kv.length() == 2) {
             ret.insert(QUrl::fromPercentEncoding(kv[0]), QUrl::fromPercentEncoding(kv[1]));
